<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>MPRISFactory</name>
    <message>
        <location filename="../mprisfactory.cpp" line="29"/>
        <source>MPRIS Plugin</source>
        <translation>MPRIS プラグイン</translation>
    </message>
    <message>
        <location filename="../mprisfactory.cpp" line="49"/>
        <source>About MPRIS Plugin</source>
        <translation>MPRIS プラグインについて</translation>
    </message>
    <message>
        <location filename="../mprisfactory.cpp" line="50"/>
        <source>Qmmp MPRIS Plugin</source>
        <translation>QMMP MPRIS プラグイン</translation>
    </message>
    <message>
        <location filename="../mprisfactory.cpp" line="51"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>
